<?php
// Verbindung zur Datenbank herstellen
$servername = "192.168.y.x";
$username = "dbuser";
$password = "password";
$dbname = "sensor_data";

$conn = new mysqli($servername, $username, $password, $dbname);

if ($conn->connect_error) {
    die("Verbindung zur Datenbank fehlgeschlagen: " . $conn->connect_error);
}

// Datenbankabfrage, um Temperaturdaten abzurufen
$sql = "SELECT date, time, Gaswiderstand FROM sensor_data ORDER BY date, time";
$result = $conn->query($sql);

if ($result->num_rows > 0) {
    // Daten für das Diagramm vorbereiten
    $data = array();

    while ($row = $result->fetch_assoc()) {
        $datetime = $row['date'] . ' ' . $row['time'];
        $timestamp = strtotime($datetime);
        $x = $timestamp;
        $temperature = $row['Gaswiderstand'];

        $data[] = array("x" => $x, "y" => $temperature);
    }

    // Diagramm erstellen
    $width = 2000;
    $height = 400;
    $image = imagecreatetruecolor($width, $height);
    $background_color = imagecolorallocate($image, 255, 255, 255);
    $line_color = imagecolorallocate($image, 0, 0, 0);

    imagefill($image, 0, 0, $background_color);

    // Achsen zeichnen
    imageline($image, 50, 350, 50, 50, $line_color); // Y-Achse
    imageline($image, 50, 350, 1950, 350, $line_color); // X-Achse

    // Beschriftungen der Achsen
    $max_temperature = max(array_column($data, 'y'));
    $min_temperature = min(array_column($data, 'y'));
    $temperature_range = $max_temperature - $min_temperature;

    // Y-Achse beschriften
    $num_ticks = 10;
    $tick_interval = $temperature_range / $num_ticks;
    $tick_height = ($height - 100) / $num_ticks;

    for ($i = 0; $i <= $num_ticks; $i++) {
        $y = 350 - ($i * $tick_height);
        $temperature = round($min_temperature + ($i * $tick_interval), 1);
        imagestring($image, 5, 20, $y - 7, $temperature, $line_color);
        imageline($image, 45, $y, 50, $y, $line_color);
    }

    // X-Achse beschriften
    $first_x = $data[0]['x'];
    $x_labels = array();
    $previous_date = '';

    foreach ($data as $point) {
        $x = $point['x'];
        $date = date('Y-m-d', $x);

        if ($date !== $previous_date) {
            $x_labels[] = array("x" => $x, "date" => $date);
            $previous_date = $date;
        }
    }

    $num_x_labels = 15; // Anzahl der anzuzeigenden Datumsbeschriftungen
    $step = ceil(count($x_labels) / $num_x_labels);

    for ($i = 0; $i < count($x_labels); $i += $step) {
        $label = $x_labels[$i];
        $x = 50 + (($label['x'] - $first_x) / ($data[count($data) - 1]['x'] - $first_x) * 1900);
        imagestring($image, 5, $x - 30, 360, $label['date'], $line_color);
    }

    // Temperaturdaten zeichnen
    foreach ($data as $point) {
        $x = 50 + (($point['x'] - $first_x) / ($data[count($data) - 1]['x'] - $first_x) * 1900);
        $y = 350 - (($point['y'] - $min_temperature) / $temperature_range * ($height - 100));
        imagefilledellipse($image, $x, $y, 5, 5, $line_color);
    }

    // Diagramm anzeigen oder speichern
    header("Content-type: image/png");
    imagepng($image);

    // Verbindung zur Datenbank schließen
    $conn->close();
} else {
    echo "Keine Daten gefunden.";
}
?>
